body,body>div:first-child,div#__next,div#__next>div,html{height:100%}body,html{padding:0;margin:0;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif}a{color:inherit;text-decoration:none}*{-webkit-box-sizing:border-box;box-sizing:border-box}